@@ -63,7 +63,7 @@ sub handle_error {
         $remedy->guess_encodings($self->guess_encodings);
         return $remedy;
     }
-    elsif ($errors[0] =~ /^:(\d+): parser error : Entity 'nbsp' not defined/) {
+    elsif ($errors[0] =~ /^:(\d+): parser error : Entity '(.*)' not defined/) {
         my $line = $1;
         my $pos = $self->get_pos($errors[2]);
         defined($pos) or Carp::carp("Can't get pos from $error"), return;
